pub enum ShapedTextSliceType {
Word,
WhiteSpace,
WordAndWhiteSpace,
}Variants
Word
A ShapedTextSlice that is a word that is not followed by white space.
WhiteSpace
A ShapedTextSlice composed of only white space glyphs.
WordAndWhiteSpace
A ShapedTextSlice that is a word that ends with a white space glyphs.
Typically whitespace glyphs are placed in a separate slice, but that may not be
the case with white-space: break-spaces.