pub struct ShapedTextSlicer {
current_glyph_offset: usize,
current_character_offset: usize,
shaped_text: Arc<ShapedText>,
}Expand description
A data structure used to efficiently slice up a ShapedText into ShapedTextSlices.
Fields
current_glyph_offset: usizecurrent_character_offset: usizeshaped_text: Arc<ShapedText>Implementations
Sourceimpl ShapedTextSlicer
impl ShapedTextSlicer
pub fn new(shaped_text: Arc<ShapedText>) -> Self
Sourcepub fn slice_until_character_offset(
&mut self,
desired_character_offset: usize,
slice_type: ShapedTextSliceType,
) -> Option<Arc<ShapedTextSlice>>
pub fn slice_until_character_offset( &mut self, desired_character_offset: usize, slice_type: ShapedTextSliceType, ) -> Option<Arc<ShapedTextSlice>>
Given a desired character offset, consume glyphs until that character offset
is reached (inclusive of glyphs that come from zero characters). Return those
glyphs as a ShapedTextSlice tagged with the given whitespace-related
properties. Returns None if the resulting slice would not hold any glyphs.